/*
 * Copyright (c) 2015-2018, Sonos, Inc.
 *
 * SPDX-License-Identifier:	GPL-2.0
 *
 * Sonos Signature format support
 */

#ifndef SONOS_SIGNATURE_KEYS_H
#define SONOS_SIGNATURE_KEYS_H

#include <linux/types.h>

typedef struct {
	const uint8_t *der;
	size_t derLen;
	const char *name;
} SonosRsaKeyEntry;

extern const SonosRsaKeyEntry * g_SonosSigningKeys[];

extern void sonosInitKeyTable(void);

#endif
